==> go.php?file=Boss_shieldsmonitor1.000.zip: Boss_shieldsmonitor/Boss_shieldsmonitor.lua <==
﻿function Jaraxxus_OnLoad2()

	jxlocale()

	bossdamagedone=0
	jxvalbitnada="0"
	boosshieldson=0
	jxshieldamount=0


	if(jxwelwidth2 == nil) then jxwelwidth2 = 185 end
	if(jxwelheight2 == nil) then jxwelheight2 = 66 end

if (jxgalochki2==nil) then
jxgalochki2={"yes",
"yes"
}
end
	jxnotice=GetTime()

	SLASH_JARAXXUSM1 = "/boss_shieldsmonitor"
	SLASH_JARAXXUSM2 = "/bsm"
	SLASH_JARAXXUSM3 = "/boss_shield"
	SLASH_JARAXXUSM4 = "/shield"
	SLASH_JARAXXUSM5 = "/shields"
	SLASH_JARAXXUSM6 = "/щиты"
	SLASH_JARAXXUSM7 = "/щит"
	SLASH_JARAXXUSM8 = "/boss_shields"
	SlashCmdList["JARAXXUSM"] = JARAXXUSM_Command


	Jaraxxus:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
	Jaraxxus:RegisterEvent("PLAYER_REGEN_DISABLED")
	Jaraxxus:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	Jaraxxus:RegisterEvent("PLAYER_ALIVE")


end



function jxcoli_OnUpdate2(arg1)

if jxnotice and arg1>jxnotice+15 then
jxnotice=nil
if IsAddOnLoaded("Jaraxxus_DebuffHealingMonitor") then
jxnotice2=arg1
print ("|cff00ff00Boss_shieldsmonitor|r > |cffff0000Attention!|r You have to delete 'Jaraxxus_DebuffHealingMonitor' addon, otherwise it will not work with boss' shields!")
end
end

if jxnotice2 and arg1>jxnotice2+15 then
jxnotice2=nil
print ("|cff00ff00Boss_shieldsmonitor|r > |cffff0000Attention!|r You have to delete 'Jaraxxus_DebuffHealingMonitor' addon, otherwise it will not work with boss' shields!")
end


if boosshieldson==1 then


if(jxgalochki2[2]=="yes")then
jxstavtochku(jxshieldamount-bossdamagedone)
jxdamsh:SetText(jxstinga2)
end

jxkastitsa=arg1-jxtimebcastGT

if jxshieldtime>0 then
jxostalos=jxshieldtime-jxkastitsa
jxostalos=jxostalos*10
jxostalos=math.ceil(jxostalos)
jxostalos=jxostalos/10
if(jxgalochki2[1]=="yes")then
if math.ceil(jxostalos)==jxostalos then
jxdamsh2:SetText(jxostalos..".0 / "..jxshieldtime..".0")
else
jxdamsh2:SetText(jxostalos.." / "..jxshieldtime..".0")
end
end

jxvelcastbar:SetWidth(jxkastitsa*(jxcolishieldmini:GetWidth()-8)/jxshieldtime)

else

jxvelcastbar:SetWidth(0.01)
jxdamsh2:SetText(" ")

end--jxshieldtime>0





if bossdamagedone==0 then
jxvelshieldbar:SetWidth(0.02)
else
jxvelshieldbar:SetWidth(bossdamagedone*(jxcolishieldmini:GetWidth()-8)/jxshieldamount)
end



jxvelshieldbar:SetWidth(bossdamagedone*(jxcolishieldmini:GetWidth()-8)/jxshieldamount)


if jxvelshieldbar:GetWidth()>jxvelcastbar:GetWidth() then
jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(0, 1, 0, 0.3)
else
jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(1, 0, 0, 0.3)
end


if jxvelcastbar:GetWidth()>((jxcolishieldmini:GetWidth()-8)+jxcolishieldmini:GetWidth()*0.1) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end


--ыытест
if UnitName("boss1")==nil then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end




end
end










function Jaraxxus_OnEvent2(self,event,...)
local arg1, arg2, arg3,arg4,arg5,arg6,arg7,arg8,arg9,arg10,arg11,arg12,arg13,arg14,arg15,arg16,arg17,arg18,arg19,arg20 = ...


if event == "PLAYER_REGEN_DISABLED" then
if jxbilresnut and GetTime()<jxbilresnut+3 then
else
	bossdamagedone=0
	jxvalbitnada="0"
	boosshieldson=0

if jxcolishieldmini:IsShown() then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end
end
end


if event == "ZONE_CHANGED_NEW_AREA" then

jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()

end

if event == "PLAYER_ALIVE" then
jxbilresnut=GetTime()
end


if GetNumRaidMembers() > 0 and event == "COMBAT_LOG_EVENT_UNFILTERED" then



--1 щит совета
if arg2=="SPELL_AURA_APPLIED" and (arg9==82631 or arg9==92512 or arg9==92513 or arg9==92514) then

if arg9==82631 then
jxshieldamount=500000
jxshieldtime=0
end
if arg9==92512 then
jxshieldamount=1500000
jxshieldtime=0
end
if arg9==92513 then
jxshieldamount=700000
jxshieldtime=0
end
if arg9==92514 then
jxshieldamount=2000000
jxshieldtime=0
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end


if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==82631 or arg9==92512 or arg9==92513 or arg9==92514) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()

end

--2 щит совета
if arg2=="SPELL_AURA_APPLIED" and (arg9==83718 or arg9==92541 or arg9==92542 or arg9==92543) then

if arg9==83718 then
jxshieldamount=500000
jxshieldtime=30
end
if arg9==92541 then
jxshieldamount=1650000
jxshieldtime=30
end
if arg9==92542 then
jxshieldamount=650000
jxshieldtime=30
end
if arg9==92543 then
jxshieldamount=2100000
jxshieldtime=30
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end


if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==83718 or arg9==92541 or arg9==92542 or arg9==92543) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end

--щит пробивается раньше
if arg2=="SPELL_DAMAGE" and boosshieldson==1 and arg9==83760 then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end



--щит конклава
if arg2=="SPELL_AURA_APPLIED" and (arg9==95865 or arg9==93059) then
if arg9==95865 then
jxshieldamount=450000
jxshieldtime=0
end
if arg9==93059 then
jxshieldamount=150000
jxshieldtime=0
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end

if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==95865 or arg9==93059) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end






if(arg6==jxvalbitnada and boosshieldson==1) then


if arg2=="DAMAGE_SHIELD_MISSED" or arg2=="SPELL_PERIODIC_MISSED" or arg2=="SPELL_MISSED" or arg2=="RANGE_MISSED" then
if arg13 then
bossdamagedone=bossdamagedone+arg13
end
end


if arg2=="SWING_MISSED" then
if arg10 then
bossdamagedone=bossdamagedone+arg10
end
end


if arg2=="SPELL_PERIODIC_DAMAGE" or arg2=="SPELL_DAMAGE" or arg2=="RANGE_DAMAGE" or arg2=="DAMAGE_SHIELD" then
if arg17 and arg17>0 then
bossdamagedone=bossdamagedone+arg17
end
end


if arg2=="SWING_DAMAGE" then
if arg14 and arg14>0 then
bossdamagedone=bossdamagedone+arg14
end
end


end



end
end


function jx_colshieldmini()
jxcolishieldmini:Show()
jxvelcastbar:Show()
jxvelshieldbar:Show()
if (jxcolishieldspamno==nil) then

jxvelshieldbar.texture = jxvelshieldbar:CreateTexture()
jxdamsh = jxcolishieldmini:CreateFontString("jxcolshield")
jxdamsh:SetFont(GameFontNormal:GetFont(), 22)
jxdamsh:SetWidth(120)
jxdamsh:SetHeight(15)
if(jxgalochki2[2]=="yes")then
jxdamsh:SetText(jxshield1)
end
jxdamsh:SetJustifyH("RIGHT")
jxcolishieldmini.texture = jxdamsh
jxdamsh:SetPoint("BOTTOMLEFT",-1,9)



jxdamsh2 = jxcolishieldmini:CreateFontString("jxcoltim")
jxdamsh2:SetFont(GameFontNormal:GetFont(), 15)
jxdamsh2:SetWidth(110)
jxdamsh2:SetHeight(15)
if(jxgalochki2[1]=="yes")then
jxdamsh2:SetText(jxcast1)
end
jxdamsh2:SetJustifyH("RIGHT")
jxcolishieldmini.texture = jxdamsh2
jxdamsh2:SetPoint("TOPLEFT",5,-6)

jxcolishieldspamno=1
end
jxchangewidth()
end


function jxchangewidth()
jxcolishieldmini:SetWidth(jxwelwidth2)
if jxgalochki2[1]=="no" then jxdamsh2:SetText("") else jxdamsh2:SetText(jxcast1) end
if jxgalochki2[2]=="no" then jxdamsh:SetText("") else jxdamsh:SetText(jxshield1) end
jxcolishieldmini:SetHeight(jxwelheight2)
jxvelcastbar:SetHeight((jxcolishieldmini:GetHeight()-8)*(20/46))
jxvelshieldbar:SetHeight((jxcolishieldmini:GetHeight()-8)*(26/46))



if boosshieldson==0 then
jxvelcastbar:SetWidth((jxcolishieldmini:GetWidth()-8)-jxcolishieldmini:GetWidth()*0.3)
jxvelshieldbar:SetWidth(jxcolishieldmini:GetWidth()-8)
end



end



--=========МЕНЮ
function JARAXXUSM_Command(msg)

jxmenu:Show()
jx_colshieldmini()
--ВРЕМЕННО ПРИСВАИВАЕМ

jxvelcastbar:SetWidth((jxcolishieldmini:GetWidth()-8)-jxcolishieldmini:GetWidth()*0.3)
jxvelshieldbar:SetWidth(jxcolishieldmini:GetWidth()-8)

jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(0, 1, 0, 0.3)
--


if (jxcolishieldspamno2==nil) then
jxdamsh3 = jxmenu:CreateFontString("")
jxdamsh3:SetFont(GameFontNormal:GetFont(), 11)
jxdamsh3:SetWidth(180)
jxdamsh3:SetHeight(15)
jxdamsh3:SetText("")
jxdamsh3:SetJustifyH("TOP")
--jxcolishieldmini.texture = jxdamsh3
jxdamsh3:SetPoint("TOP",0,-76)


jxdamsh4 = jxmenu:CreateFontString("")
jxdamsh4:SetFont(GameFontNormal:GetFont(), 11)
jxdamsh4:SetWidth(180)
jxdamsh4:SetHeight(15)
jxdamsh4:SetText("")
jxdamsh4:SetJustifyH("TOP")
--jxcolishieldmini.texture = jxdamsh4
jxdamsh4:SetPoint("TOP",0,-136)

jxcolishieldspamno2=1
end

jxrelookmenu()




end

--=====КОНЕЦ МЕНЮ

function jxgalka(nomersmeni)
if jxgalochki2[nomersmeni]=="yes" then jxgalochki2[nomersmeni]="no" else jxgalochki2[nomersmeni]="yes" end

jxrelookmenu()
jx_colshieldmini()
end


function jxdefault()
jxgalochki2={"yes",
"yes"
}
jxwelwidth2 = 150
jxwelheight2 = 54
jx_colshieldmini()
jxrelookmenu()


		jxcolishieldmini:ClearAllPoints()
		jxcolishieldmini:SetPoint("CENTER",UIParent,"CENTER",-150,-75)
end


function jxrelookmenu()
--перепроверяем галочки и прописываем все



if(jxgalochki2[1]=="yes")then jxmenu_CheckButton1:SetChecked() else jxmenu_CheckButton1:SetChecked(false) end
if(jxgalochki2[2]=="yes")then jxmenu_CheckButton2:SetChecked() else jxmenu_CheckButton2:SetChecked(false) end


if jxmenu_CheckButton1:GetChecked()==nil and jxmenu_CheckButton2:GetChecked()==nil then
jxdamsh3:SetText("("..jxbetween.." |cff00ff0030|r "..jxand.." 999)")
jxdamsh4:SetText("("..jxbetween.." |cff00ff0030|r "..jxand.." 999)")
else
jxdamsh3:SetText("("..jxbetween.." |cffff0000150|r "..jxand.." 999)")
jxdamsh4:SetText("("..jxbetween.." |cffff000054|r "..jxand.." 999)")
if jxwelwidth2<150 then jxwelwidth2=150 end
if jxwelheight2<54 then jxwelheight2=54 end
end

--едитбоксы
jxmenu_width1:SetText(jxwelwidth2)
jxmenu_heigh1:SetText(jxwelheight2)


end

function jxApply()
jxcolishieldmini:Show()
jxvelcastbar:Show()
jxvelshieldbar:Show()
if jxmenu_width1:GetNumber()>29 and jxmenu_width1:GetNumber()<1000 then jxwelwidth2=jxmenu_width1:GetNumber() end
if jxmenu_heigh1:GetNumber()>29 and jxmenu_heigh1:GetNumber()<1000 then jxwelheight2=jxmenu_heigh1:GetNumber() end
jxrelookmenu()
jxchangewidth()
jxmenu_width1:ClearFocus()
jxmenu_heigh1:ClearFocus()
end

function jxstavtochku(jxstinga)

if string.len(jxstinga)>6 then
jxstinga2=string.sub(jxstinga, 1, 1).."."..string.sub(jxstinga, 2, 4).."."..string.sub(jxstinga, 5)
elseif string.len(jxstinga)>3 then
jxstinga2=string.sub(jxstinga, 1, string.len(jxstinga)-3).."."..string.sub(jxstinga, string.len(jxstinga)-2)
else
jxstinga2=jxstinga
end

end

function out(text)
DEFAULT_CHAT_FRAME:AddMessage(text)
UIErrorsFrame:AddMessage(text, 1.0, 1.0, 0, 1, 10)
end

==> go.php?file=Boss_shieldsmonitor1.001.zip: Boss_shieldsmonitor/Boss_shieldsmonitor.lua <==
﻿function Jaraxxus_OnLoad2()

	jxlocale()

	bossdamagedone=0
	jxvalbitnada="0"
	boosshieldson=0
	jxshieldamount=0


	if(jxwelwidth2 == nil) then jxwelwidth2 = 185 end
	if(jxwelheight2 == nil) then jxwelheight2 = 66 end

if (jxgalochki2==nil) then
jxgalochki2={"yes",
"yes"
}
end
	jxnotice=GetTime()

	SLASH_JARAXXUSM1 = "/boss_shieldsmonitor"
	SLASH_JARAXXUSM2 = "/bsm"
	SLASH_JARAXXUSM3 = "/boss_shield"
	SLASH_JARAXXUSM4 = "/shield"
	SLASH_JARAXXUSM5 = "/shields"
	SLASH_JARAXXUSM6 = "/щиты"
	SLASH_JARAXXUSM7 = "/щит"
	SLASH_JARAXXUSM8 = "/boss_shields"
	SlashCmdList["JARAXXUSM"] = JARAXXUSM_Command


	Jaraxxus:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")


end



function jxcoli_OnUpdate2(arg1)

if jxnotice and arg1>jxnotice+15 then
jxnotice=nil
if IsAddOnLoaded("Jaraxxus_DebuffHealingMonitor") then
jxnotice2=arg1
print ("|cff00ff00Boss_shieldsmonitor|r > |cffff0000Attention!|r You have to delete 'Jaraxxus_DebuffHealingMonitor' addon, otherwise it will not work with boss' shields!")
end
end

if jxnotice2 and arg1>jxnotice2+15 then
jxnotice2=nil
print ("|cff00ff00Boss_shieldsmonitor|r > |cffff0000Attention!|r You have to delete 'Jaraxxus_DebuffHealingMonitor' addon, otherwise it will not work with boss' shields!")
end


if boosshieldson==1 then


if(jxgalochki2[2]=="yes")then
jxstavtochku(jxshieldamount-bossdamagedone)
jxdamsh:SetText(jxstinga2)
end

jxkastitsa=arg1-jxtimebcastGT

if jxshieldtime>0 then
jxostalos=jxshieldtime-jxkastitsa
jxostalos=jxostalos*10
jxostalos=math.ceil(jxostalos)
jxostalos=jxostalos/10
if(jxgalochki2[1]=="yes")then
if math.ceil(jxostalos)==jxostalos then
jxdamsh2:SetText(jxostalos..".0 / "..jxshieldtime..".0")
else
jxdamsh2:SetText(jxostalos.." / "..jxshieldtime..".0")
end
end

jxvelcastbar:SetWidth(jxkastitsa*(jxcolishieldmini:GetWidth()-8)/jxshieldtime)

else

jxvelcastbar:SetWidth(0.01)
jxdamsh2:SetText(" ")

end--jxshieldtime>0





if bossdamagedone==0 then
jxvelshieldbar:SetWidth(0.02)
else
jxvelshieldbar:SetWidth(bossdamagedone*(jxcolishieldmini:GetWidth()-8)/jxshieldamount)
end



jxvelshieldbar:SetWidth(bossdamagedone*(jxcolishieldmini:GetWidth()-8)/jxshieldamount)


if jxvelshieldbar:GetWidth()>jxvelcastbar:GetWidth() then
jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(0, 1, 0, 0.3)
else
jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(1, 0, 0, 0.3)
end


if jxvelcastbar:GetWidth()>((jxcolishieldmini:GetWidth()-8)+jxcolishieldmini:GetWidth()*0.1) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end



if UnitName("boss1")==nil then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end




end
end










function Jaraxxus_OnEvent2(self,event,...)
local arg1, arg2, arg3,arg4,arg5,arg6,arg7,arg8,arg9,arg10,arg11,arg12,arg13,arg14,arg15,arg16,arg17,arg18,arg19,arg20 = ...

if GetNumRaidMembers() > 0 and event == "COMBAT_LOG_EVENT_UNFILTERED" then



--1 щит совета
if arg2=="SPELL_AURA_APPLIED" and (arg9==82631 or arg9==92512 or arg9==92513 or arg9==92514) then
if psraidoptionson and psraidoptionson[3] and psraidoptionson[3][3] and psraidoptionson[3][3][8] and psraidoptionson[3][3][8]==0 then
else

if arg9==82631 then
jxshieldamount=500000
jxshieldtime=0
end
if arg9==92512 then
jxshieldamount=1500000
jxshieldtime=0
end
if arg9==92513 then
jxshieldamount=700000
jxshieldtime=0
end
if arg9==92514 then
jxshieldamount=2000000
jxshieldtime=0
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end
end


if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==82631 or arg9==92512 or arg9==92513 or arg9==92514) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()

end

--2 щит совета
if arg2=="SPELL_AURA_APPLIED" and (arg9==83718 or arg9==92541 or arg9==92542 or arg9==92543) then
if psraidoptionson and psraidoptionson[3] and psraidoptionson[3][3] and psraidoptionson[3][3][9] and psraidoptionson[3][3][9]==0 then
else

if arg9==83718 then
jxshieldamount=500000
jxshieldtime=30
end
if arg9==92541 then
jxshieldamount=1650000
jxshieldtime=30
end
if arg9==92542 then
jxshieldamount=650000
jxshieldtime=30
end
if arg9==92543 then
jxshieldamount=2100000
jxshieldtime=30
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end
end


if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==83718 or arg9==92541 or arg9==92542 or arg9==92543) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end

--щит пробивается раньше
if arg2=="SPELL_DAMAGE" and boosshieldson==1 and arg9==83760 then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end



--щит конклава
if arg2=="SPELL_AURA_APPLIED" and (arg9==95865 or arg9==93059) then
if psraidoptionson and psraidoptionson[4] and psraidoptionson[4][1] and psraidoptionson[4][1][9] and psraidoptionson[4][1][9]==0 then
else
if arg9==95865 then
jxshieldamount=450000
jxshieldtime=0
end
if arg9==93059 then
jxshieldamount=150000
jxshieldtime=0
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()

end
end

if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==95865 or arg9==93059) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end







--щит магматрона
if arg2=="SPELL_AURA_APPLIED" and (arg9==79582 or arg9==91516 or arg9==91517 or arg9==91518) then
if psraidoptionson and psraidoptionson[2] and psraidoptionson[2][2] and psraidoptionson[2][2][17] and psraidoptionson[2][2][17]==1 then

if arg9==79582 then
jxshieldamount=150000
jxshieldtime=10
end
if arg9==91516 then
jxshieldamount=450000
jxshieldtime=10
end
if arg9==91517 then
jxshieldamount=150000
jxshieldtime=10
end
if arg9==91518 then
jxshieldamount=450000
jxshieldtime=10
end

jxtimebcastGT=GetTime()
boosshieldson=1
bossdamagedone=0
jxvalbitnada=arg6
jx_colshieldmini()
end
end


if arg2=="SPELL_AURA_REMOVED" and boosshieldson==1 and (arg9==79582 or arg9==91516 or arg9==91517 or arg9==91518) then
jxvelcastbar:SetWidth(0.02)
jxvelshieldbar:SetWidth(0.02)
boosshieldson=0
jxcolishieldmini:Hide()
jxvelcastbar:Hide()
jxvelshieldbar:Hide()
end















if(arg6==jxvalbitnada and boosshieldson==1) then


if arg2=="DAMAGE_SHIELD_MISSED" or arg2=="SPELL_PERIODIC_MISSED" or arg2=="SPELL_MISSED" or arg2=="RANGE_MISSED" then
if arg13 then
bossdamagedone=bossdamagedone+arg13
end
end


if arg2=="SWING_MISSED" then
if arg10 then
bossdamagedone=bossdamagedone+arg10
end
end


if arg2=="SPELL_PERIODIC_DAMAGE" or arg2=="SPELL_DAMAGE" or arg2=="RANGE_DAMAGE" or arg2=="DAMAGE_SHIELD" then
if arg17 and arg17>0 then
bossdamagedone=bossdamagedone+arg17
end
end


if arg2=="SWING_DAMAGE" then
if arg14 and arg14>0 then
bossdamagedone=bossdamagedone+arg14
end
end


end



end
end


function jx_colshieldmini()
jxcolishieldmini:Show()
jxvelcastbar:Show()
jxvelshieldbar:Show()
if (jxcolishieldspamno==nil) then

jxvelshieldbar.texture = jxvelshieldbar:CreateTexture()
jxdamsh = jxcolishieldmini:CreateFontString("jxcolshield")
jxdamsh:SetFont(GameFontNormal:GetFont(), 22)
jxdamsh:SetWidth(120)
jxdamsh:SetHeight(15)
if(jxgalochki2[2]=="yes")then
jxdamsh:SetText(jxshield1)
end
jxdamsh:SetJustifyH("RIGHT")
jxcolishieldmini.texture = jxdamsh
jxdamsh:SetPoint("BOTTOMLEFT",-1,9)



jxdamsh2 = jxcolishieldmini:CreateFontString("jxcoltim")
jxdamsh2:SetFont(GameFontNormal:GetFont(), 15)
jxdamsh2:SetWidth(110)
jxdamsh2:SetHeight(15)
if(jxgalochki2[1]=="yes")then
jxdamsh2:SetText(jxcast1)
end
jxdamsh2:SetJustifyH("RIGHT")
jxcolishieldmini.texture = jxdamsh2
jxdamsh2:SetPoint("TOPLEFT",5,-6)

jxcolishieldspamno=1
end
jxchangewidth()
end


function jxchangewidth()
jxcolishieldmini:SetWidth(jxwelwidth2)
if jxgalochki2[1]=="no" then jxdamsh2:SetText("") else jxdamsh2:SetText(jxcast1) end
if jxgalochki2[2]=="no" then jxdamsh:SetText("") else jxdamsh:SetText(jxshield1) end
jxcolishieldmini:SetHeight(jxwelheight2)
jxvelcastbar:SetHeight((jxcolishieldmini:GetHeight()-8)*(20/46))
jxvelshieldbar:SetHeight((jxcolishieldmini:GetHeight()-8)*(26/46))



if boosshieldson==0 then
jxvelcastbar:SetWidth((jxcolishieldmini:GetWidth()-8)-jxcolishieldmini:GetWidth()*0.3)
jxvelshieldbar:SetWidth(jxcolishieldmini:GetWidth()-8)
end



end



--=========МЕНЮ
function JARAXXUSM_Command(msg)

jxmenu:Show()
jx_colshieldmini()
--ВРЕМЕННО ПРИСВАИВАЕМ

jxvelcastbar:SetWidth((jxcolishieldmini:GetWidth()-8)-jxcolishieldmini:GetWidth()*0.3)
jxvelshieldbar:SetWidth(jxcolishieldmini:GetWidth()-8)

jxvelshieldbar.texture:SetAllPoints(jxvelshieldbar)
jxvelshieldbar.texture:SetTexture(0, 1, 0, 0.3)
--


if (jxcolishieldspamno2==nil) then
jxdamsh3 = jxmenu:CreateFontString("")
jxdamsh3:SetFont(GameFontNormal:GetFont(), 11)
jxdamsh3:SetWidth(180)
jxdamsh3:SetHeight(15)
jxdamsh3:SetText("")
jxdamsh3:SetJustifyH("TOP")
--jxcolishieldmini.texture = jxdamsh3
jxdamsh3:SetPoint("TOP",0,-76)


jxdamsh4 = jxmenu:CreateFontString("")
jxdamsh4:SetFont(GameFontNormal:GetFont(), 11)
jxdamsh4:SetWidth(180)
jxdamsh4:SetHeight(15)
jxdamsh4:SetText("")
jxdamsh4:SetJustifyH("TOP")
--jxcolishieldmini.texture = jxdamsh4
jxdamsh4:SetPoint("TOP",0,-136)

jxcolishieldspamno2=1
end

jxrelookmenu()




end

--=====КОНЕЦ МЕНЮ

function jxgalka(nomersmeni)
if jxgalochki2[nomersmeni]=="yes" then jxgalochki2[nomersmeni]="no" else jxgalochki2[nomersmeni]="yes" end

jxrelookmenu()
jx_colshieldmini()
end


function jxdefault()
jxgalochki2={"yes",
"yes"
}
jxwelwidth2 = 150
jxwelheight2 = 54
jx_colshieldmini()
jxrelookmenu()


		jxcolishieldmini:ClearAllPoints()
		jxcolishieldmini:SetPoint("CENTER",UIParent,"CENTER",-150,-75)
end


function jxrelookmenu()
--перепроверяем галочки и прописываем все



if(jxgalochki2[1]=="yes")then jxmenu_CheckButton1:SetChecked() else jxmenu_CheckButton1:SetChecked(false) end
if(jxgalochki2[2]=="yes")then jxmenu_CheckButton2:SetChecked() else jxmenu_CheckButton2:SetChecked(false) end


if jxmenu_CheckButton1:GetChecked()==nil and jxmenu_CheckButton2:GetChecked()==nil then
jxdamsh3:SetText("("..jxbetween.." |cff00ff0030|r "..jxand.." 999)")
jxdamsh4:SetText("("..jxbetween.." |cff00ff0030|r "..jxand.." 999)")
else
jxdamsh3:SetText("("..jxbetween.." |cffff0000150|r "..jxand.." 999)")
jxdamsh4:SetText("("..jxbetween.." |cffff000054|r "..jxand.." 999)")
if jxwelwidth2<150 then jxwelwidth2=150 end
if jxwelheight2<54 then jxwelheight2=54 end
end

--едитбоксы
jxmenu_width1:SetText(jxwelwidth2)
jxmenu_heigh1:SetText(jxwelheight2)


end

function jxApply()
jxcolishieldmini:Show()
jxvelcastbar:Show()
jxvelshieldbar:Show()
if jxmenu_width1:GetNumber()>29 and jxmenu_width1:GetNumber()<1000 then jxwelwidth2=jxmenu_width1:GetNumber() end
if jxmenu_heigh1:GetNumber()>29 and jxmenu_heigh1:GetNumber()<1000 then jxwelheight2=jxmenu_heigh1:GetNumber() end
jxrelookmenu()
jxchangewidth()
jxmenu_width1:ClearFocus()
jxmenu_heigh1:ClearFocus()
end

function jxstavtochku(jxstinga)

if string.len(jxstinga)>6 then
jxstinga2=string.sub(jxstinga, 1, 1).."."..string.sub(jxstinga, 2, 4).."."..string.sub(jxstinga, 5)
elseif string.len(jxstinga)>3 then
jxstinga2=string.sub(jxstinga, 1, string.len(jxstinga)-3).."."..string.sub(jxstinga, string.len(jxstinga)-2)
else
jxstinga2=jxstinga
end

end

function out(text)
DEFAULT_CHAT_FRAME:AddMessage(text)
UIErrorsFrame:AddMessage(text, 1.0, 1.0, 0, 1, 10)
end
